@@ -38,14 +38,15 @@
 #' where N is the number of observations. N will be averaged over.
 #' @param Thalf Half of the time extent of the lattice
 #' @param type The function to be used to compute the effective mass values.
-#' Possibilities are "acosh", "solve", "log", "temporal", "shifted" and
-#' "weighted". While the first three assume normal cosh behaviour of the
-#' correlation function, "temporal" is desigend to remove an additional
+#' Possibilities are "acosh", "solve", "log", "temporal", "shifted",
+#' "weighted" and "power". While the first three assume normal cosh behaviour of the
+#' correlation function, "temporal" is designed to remove an additional
 #' constant stemming from temporal states in two particle correlation
 #' functions. The same for "subtracted" and "weighted", the latter for the case
 #' of two particle energies with the two particle having different energies. In
-#' the latter case only the leading polution is removed by
+#' the latter case only the leading pollution is removed by
 #' \code{removeTemporal.cf} and taken into account here.
+#' "power" assumes a powerlaw decay instead of an exponential.
 #' @param nrObs The number of "observables" included in the correlator
 #' @param replace.inf If set to \code{TRUE}, all \code{\link{Inf}} values will
 #' be replaced by \code{\link{NA}}. This is needed for instance for
@@ -133,6 +134,10 @@ effectivemass.cf <- function(cf, Thalf, type="solve", nrObs=1, replace.inf=TRUE,
     if(type == "log") {
       effMass[t2] <- log(Ratio[t2])
     }
+    else if(type == "power") {
+      tRat <- t/(t-1)
+      effMass[t2] <- log(Ratio[t2])/log(tRat[t2])
+    }
     else {
       # note: for tmax > Thalf, this will produce NA
       for(t in t2) {
